from pythonjsonlogger import jsonlogger


class StackdriverJsonFormatter(jsonlogger.JsonFormatter, object):
    def __init__(self, fmt="%(levelname) %(message)", style='%', *args, **kwargs):
        jsonlogger.JsonFormatter.__init__(self, fmt=fmt, *args, **kwargs)

    def process_log_record(self, log_record):
        log_record['severity'] = log_record['levelname']
        return super(StackdriverJsonFormatter, self).process_log_record(log_record)



import sys

logging_dict = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        "json": {
            '()': "pysdl.stackdriverjsonlogger.StackdriverJsonFormatter",
            'format': "%(levelname)s %(asctime)s %(module)s %(funcName)s %(lineno)s %(process)s %(thread)s %(message)s"
        },
        "medium": {
            'format': '%(levelname)s %(asctime)s [%(correlation_id)s] %(name)s %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'json',
            'stream': sys.stdout
        },
    },
    'loggers': {
        # Root Logger
        '': {
            'handlers': ['console'],
            'level': 'INFO',
        },
        # DB events and sql
        'django.db.backends': {
            'handlers': ['console'],
            'level': 'ERROR',
        },
        # Celery tasks will duplicate WARNING and ERROR logs here but it also helps us to catch celery issues
        # IMO duplication of ERROR and WARNING logs aren't a big deal
        'celery': {
            'handlers': ['console'],
            'level': 'WARNING',
        },
        'celery.beat': {
            'handlers': ['console'],
            'level': 'WARNING',
        },
    }
}


from setuptools import setup, find_packages

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='pysdl',
    version='1.1.0',
    url='',
    license='',
    author='NewtonX',
    author_email='',
    python_requires='>=3.4',
    test_suite="tests.tests",
    long_description=long_description,
    long_description_content_type='text/markdown',
    package_dir={'': 'src'},
    packages=find_packages("src", exclude="tests"),
    description='A python library that helps Stackdriver consume python logs appropriately built on madzak/python-json-logger',
)
